==> maleo_metadata-0.0.52.tar.gz: maleo_metadata-0.0.52/maleo_metadata/client/controllers/http/organization_role.py <==
from maleo_foundation.managers.client.maleo import MaleoClientHTTPController
from maleo_foundation.models.transfers.results.client.controllers.http import BaseClientHTTPControllerResults
from maleo_metadata.models.transfers.parameters.general.organization_role import MaleoMetadataOrganizationRoleGeneralParametersTransfers
from maleo_metadata.models.transfers.parameters.client.organization_role import MaleoMetadataOrganizationRoleClientParametersTransfers

class MaleoMetadataOrganizationRoleHTTPController(MaleoClientHTTPController):
    async def get_organization_roles(self, parameters:MaleoMetadataOrganizationRoleClientParametersTransfers.GetMultiple) -> BaseClientHTTPControllerResults:
        """Fetch organization roles from MaleoMetadata"""
        async with self._manager.get_client() as client:
            #* Define URL
            url = f"{self._manager.url.api}/v1/organization-roles/"

            #* Parse parameters to query params
            params = MaleoMetadataOrganizationRoleClientParametersTransfers.GetMultipleQuery.model_validate(parameters.model_dump()).model_dump(exclude={"sort_columns", "date_filters"}, exclude_none=True)

            #* Create headers
            headers = {
                "Content-Type": "application/json",
                "Authorization": f"Bearer {self._service_manager.token}"
            }

            #* Send request and wait for response
            response = await client.get(url=url, params=params, headers=headers)
            return BaseClientHTTPControllerResults(response=response)

    async def get_organization_role(self, parameters:MaleoMetadataOrganizationRoleGeneralParametersTransfers.GetSingle) -> BaseClientHTTPControllerResults:
        """Fetch organization role from MaleoMetadata"""
        async with self._manager.get_client() as client:
            #* Define URL
            url = f"{self._manager.url.api}/v1/organization-roles/{parameters.identifier}/{parameters.value}"

            #* Parse parameters to query params
            params = MaleoMetadataOrganizationRoleGeneralParametersTransfers.GetSingleQuery.model_validate(parameters.model_dump()).model_dump(exclude={"sort_columns", "date_filters"}, exclude_none=True)

            #* Create headers
            headers = {
                "Content-Type": "application/json",
                "Authorization": f"Bearer {self._service_manager.token}"
            }

            #* Send request and wait for response
            response = await client.get(url=url, params=params, headers=headers)
            return BaseClientHTTPControllerResults(response=response)

==> maleo_metadata-0.0.66.tar.gz: maleo_metadata-0.0.66/maleo_metadata/client/controllers/http/organization_role.py <==
from maleo_foundation.managers.client.base import BearerAuth
from maleo_foundation.managers.client.maleo import MaleoClientHTTPController
from maleo_foundation.models.transfers.results.client.controllers.http import BaseClientHTTPControllerResults
from maleo_metadata.models.transfers.parameters.general.organization_role import MaleoMetadataOrganizationRoleGeneralParametersTransfers
from maleo_metadata.models.transfers.parameters.client.organization_role import MaleoMetadataOrganizationRoleClientParametersTransfers

class MaleoMetadataOrganizationRoleHTTPController(MaleoClientHTTPController):
    async def get_organization_roles(self, parameters:MaleoMetadataOrganizationRoleClientParametersTransfers.GetMultiple) -> BaseClientHTTPControllerResults:
        """Fetch organization roles from MaleoMetadata"""
        async with self._manager.get_client() as client:
            #* Define URL
            url = f"{self._manager.url.api}/v1/organization-roles/"

            #* Parse parameters to query params
            params = MaleoMetadataOrganizationRoleClientParametersTransfers.GetMultipleQuery.model_validate(parameters.model_dump()).model_dump(exclude={"sort_columns", "date_filters"}, exclude_none=True)

            #* Create auth
            auth = BearerAuth(token=self._service_manager.token)

            #* Send request and wait for response
            response = await client.get(url=url, params=params, auth=auth)
            return BaseClientHTTPControllerResults(response=response)

    async def get_organization_role(self, parameters:MaleoMetadataOrganizationRoleGeneralParametersTransfers.GetSingle) -> BaseClientHTTPControllerResults:
        """Fetch organization role from MaleoMetadata"""
        async with self._manager.get_client() as client:
            #* Define URL
            url = f"{self._manager.url.api}/v1/organization-roles/{parameters.identifier}/{parameters.value}"

            #* Parse parameters to query params
            params = MaleoMetadataOrganizationRoleGeneralParametersTransfers.GetSingleQuery.model_validate(parameters.model_dump()).model_dump(exclude_none=True)

            #* Create auth
            auth = BearerAuth(token=self._service_manager.token)

            #* Send request and wait for response
            response = await client.get(url=url, params=params, auth=auth)
            return BaseClientHTTPControllerResults(response=response)
